==> nextcloud-13.0.1.tgz: nextcloud/apps/comments/l10n/ru.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Комментарии",
    "New comment …" : "Новый комментарий...",
    "Delete comment" : "Удалить комментарий",
    "Post" : "Опубликовать",
    "Cancel" : "Отмена",
    "Edit comment" : "Редактировать комментарий",
    "[Deleted user]" : "[Удалённый пользователь]",
    "No comments yet, start the conversation!" : "Комментарии отсутствуют, начните обсуждение!",
    "More comments …" : "Ещё комментарии...",
    "Save" : "Сохранить",
    "Allowed characters {count} of {max}" : "Допустимых символов {count} из {max}",
    "Error occurred while retrieving comment with ID {id}" : "При получении комментария с ID {id} произошла ошибка",
    "Error occurred while updating comment with id {id}" : "При обновлении комментария с id {id} произошла ошибка",
    "Error occurred while posting comment" : "При сохранении комментария произошла ошибка",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочитанный комментарий","%n непрочитанных комментариев","%n непрочитанных комментариев","%n непрочитанных комментариев"],
    "Comment" : "Комментарий",
    "You commented" : "Вы прокомментировали",
    "%1$s commented" : "%1$s прокомментировано",
    "{author} commented" : "{author} прокомментировал",
    "You commented on %1$s" : "Вы прокомментировали %1$s",
    "You commented on {file}" : "Вы прокомментировали {file}",
    "%1$s commented on %2$s" : "%1$s прокомментировано на %2$s",
    "{author} commented on {file}" : "{author} прокомментировал {file}",
    "<strong>Comments</strong> for files" : "<strong>Комментарии</strong> к файлам",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Вы были упомянуты в комментарии к файлу «%s» пользователем, учётная запись которого была удалена",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Вы были упомянуты в комментарии к файлу «{file}» пользователем, учётная запись которого была удалена",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s упомянул вас в комментарии к \"%2$s\"",
    "{user} mentioned you in a comment on “{file}”" : "{user} упомянул вас в комментарии к “{file}”.",
    "Unknown user" : "Неизвестный пользователь",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Пользователь (удалённый в настоящее время) упомянул вас в комментарии к “%s”.",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Пользователь (удалённый в настоящее время) упомянул вас в комментарии к “{file}”."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/comments/l10n/ru.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Редактировать комментарий",
    "Delete comment" : "Удалить комментарий",
    "New comment …" : "Новый комментарий…",
    "Post" : "Опубликовать",
    "Cancel" : "Отмена",
    "[Deleted user]" : "[Удалённый пользователь]",
    "Comments" : "Комментарии",
    "No comments yet, start the conversation!" : "Комментарии отсутствуют, начните обсуждение!",
    "More comments …" : "Ещё комментарии…",
    "Save" : "Сохранить",
    "Allowed characters {count} of {max}" : "Допустимых символов {count} из {max}",
    "Error occurred while retrieving comment with ID {id}" : "При получении комментария с ID {id} произошла ошибка",
    "Error occurred while updating comment with id {id}" : "При обновлении комментария с id {id} произошла ошибка",
    "Error occurred while posting comment" : "При сохранении комментария произошла ошибка",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочитанный комментарий","%n непрочитанных комментариев","%n непрочитанных комментариев","%n непрочитанных комментариев"],
    "Comment" : "Комментарий",
    "You commented" : "Вы прокомментировали",
    "%1$s commented" : "%1$s прокомментировано",
    "{author} commented" : "{author} прокомментировал",
    "You commented on %1$s" : "Вы прокомментировали %1$s",
    "You commented on {file}" : "Вы прокомментировали {file}",
    "%1$s commented on %2$s" : "%1$s прокомментировано на %2$s",
    "{author} commented on {file}" : "{author} прокомментировал {file}",
    "<strong>Comments</strong> for files" : "<strong>Комментарии</strong> к файлам",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Вы были упомянуты в комментарии к файлу «%s» пользователем, учётная запись которого была удалена",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Вы были упомянуты в комментарии к файлу «{file}» пользователем, учётная запись которого была удалена",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s упомянул вас в комментарии к \"%2$s\"",
    "{user} mentioned you in a comment on “{file}”" : "{user} упомянул вас в комментарии к “{file}”.",
    "Unknown user" : "Неизвестный пользователь",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Пользователь (удалённый в настоящее время) упомянул вас в комментарии к “%s”.",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Пользователь (удалённый в настоящее время) упомянул вас в комментарии к “{file}”."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
